sagar
=====

.. image :: https://travis-ci.org/scut-ccmp/sagar.svg?branch=master
    :target: https://travis-ci.org/scut-ccmp/sagar
    :alt: Build Status

.. image ::https://codecov.io/gh/scut-ccmp/sagar/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/scut-ccmp/sagar
    :alt: codecov

.. image :: https://readthedocs.org/projects/sagar/badge/?version=latest
    :target: https://sagar.readthedocs.io/
    :alt: Documentation Status

.. image :: https://badges.frapsoft.com/os/mit/mit.svg?v=103
    :target: https://opensource.org/licenses/mit-license.php
    :alt: MIT Licence

.. image :: https://badges.frapsoft.com/os/v1/open-source.svg?v=103
    :target: https://opensource.org/licenses/mit-license.php
    :alt: Open Source Love

.. image :: https://img.shields.io/pypi/pyversions/ansicolortags.svg
    :target: https://pypi.python.org/pypi/ansicolortags/
    :alt: PyPI pyversions

Introduction
++++++++++++

sagar is short for (S)Tructures of (A)lloys (G)eneration (A)nd (R)ecognition.

It is a library with some uitils to deal grid site
 structures.
